BuildInfo

Struct BuildInfo 

pub struct BuildInfo {
    pub product_config: Option<String>,
    pub board_config: Option<String>,
    pub version: Option<String>,
    pub latest_commit_date: Option<String>,
    pub platform_version: Option<String>,
    pub product_version: Option<String>,
    /* private fields */
}

Fields

product_config: Option<String>

A description of the product configuration used at build time, determined by the value passed as PRODUCT in ‘fx set’. See ‘fx list-products’ for a list of possible values.

board_config: Option<String>

A description of the board configuration used at build time, determined by the value passed as BOARD in ‘fx set’. See fx list-boards for a list of possible values.

version: Option<String>

A description of the version of the build. Defaults to the same string as latest_commit_date.

latest_commit_date: Option<String>

The timestamp of the most recent commit to the integration repository (specifically, the “CommitDate” field) formatted in strict ISO 8601 format in the UTC timezone. Example: “2019-03-28T15:42:20+00:00”

platform_version: Option<String>

The version of the Fuchsia platform included in the build. Provided by Assembly from platform artifacts.

product_version: Option<String>

The product version of this build. Provided in Assembly product configuration. Defaults to the same value as version.